import type * as functions from 'firebase-functions';
import { type Crypter } from './crypter';
import { type DatabaseType } from './DatabaseType';
import { type FirebaseFunctionType } from './FirebaseFunction';
import { type FunctionType } from './FunctionType';
import { type ValidReturnType } from './ValidReturnType';
export type FirebaseFunctionDescriptor<T extends FunctionType<unknown, ValidReturnType, unknown>> = () => FirebaseFunctionType<T>;
export declare namespace FirebaseFunctionDescriptor {
    type Parameters<T extends FirebaseFunctionDescriptor<FunctionType<unknown, ValidReturnType, unknown>>> = T extends FirebaseFunctionDescriptor<infer U> ? U extends FunctionType<infer V, ValidReturnType, unknown> ? V : never : never;
    type ReturnType<T extends FirebaseFunctionDescriptor<FunctionType<unknown, ValidReturnType, unknown>>> = T extends FirebaseFunctionDescriptor<infer U> ? U extends FunctionType<unknown, infer V, unknown> ? V : never : never;
    type FlattenParameters<T extends FirebaseFunctionDescriptor<FunctionType<unknown, ValidReturnType, unknown>>> = T extends FirebaseFunctionDescriptor<infer U> ? U extends FunctionType<unknown, ValidReturnType, infer V> ? V : Parameters<T> : never;
    function create<T extends FunctionType<unknown, ValidReturnType, unknown>>(firebaseFunctions: FirebaseFunctionType<T>): FirebaseFunctionDescriptor<T>;
}
export type FirebaseFunctionsType = FirebaseFunctionDescriptor<FunctionType<unknown, ValidReturnType, unknown>> | {
    [key: string]: FirebaseFunctionsType;
};
export type FirebaseRunnableFunctions = (functions.HttpsFunction & functions.Runnable<unknown>) | {
    [key: string]: FirebaseRunnableFunctions;
};
export declare function createFirebaseFunctions(firebaseFunctions: FirebaseFunctionsType, getCryptionKeys: (databaseType: DatabaseType) => {
    cryptionKeys: Crypter.Keys;
    callSecretKey: string;
}): FirebaseRunnableFunctions;
